@@ -220,8 +220,7 @@ class NTMPredictor(Predictor):
         serializer=RecordSerializer(),
         deserializer=RecordDeserializer(),
     ):
-        """
-        Initialization for NTMPredictor class.
+        """Initialization for NTMPredictor class.
 
         Args:
             endpoint_name (str): Name of the Amazon SageMaker endpoint to which
@@ -251,8 +250,7 @@ class NTMModel(Model):
     """
 
     def __init__(self, model_data, role, sagemaker_session=None, **kwargs):
-        """
-        Initialization for NTMModel class.
+        """Initialization for NTMModel class.
 
         Args:
             model_data (str): The S3 location of a SageMaker model data
