@@ -35,6 +35,7 @@ def retrieve(
     accelerator_type=None,
     image_scope=None,
     container_version=None,
+    distribution=None,
 ):
     """Retrieves the ECR URI for the Docker image matching the given arguments.
 
@@ -54,6 +55,8 @@ def retrieve(
             Valid values: "training", "inference", "eia". If ``accelerator_type`` is set,
             ``image_scope`` is ignored.
         container_version (str): the version of docker image
+        distribution (dict): A dictionary with information on how to run distributed training
+            (default: None).
 
     Returns:
         str: the ECR URI for the corresponding SageMaker Docker image.
@@ -77,10 +80,29 @@ def retrieve(
     processor = _processor(
         instance_type, config.get("processors") or version_config.get("processors")
     )
+
     tag = _format_tag(
-        version_config.get("tag_prefix", version), processor, py_version, container_version
+        version_config.get("tag_prefix", version),
+        processor,
+        py_version,
+        container_version,
     )
 
+    if _should_auto_select_container_version(instance_type, distribution):
+        container_versions = {
+            "tensorflow-2.3-gpu-py37": "cu110-ubuntu18.04-v3",
+            "tensorflow-2.3.1-gpu-py37": "cu110-ubuntu18.04",
+            "tensorflow-1.15-gpu-py37": "cu110-ubuntu18.04-v8",
+            "tensorflow-1.15.4-gpu-py37": "cu110-ubuntu18.04",
+            "mxnet-1.8-gpu-py37": "cu110-ubuntu16.04-v1",
+            "mxnet-1.8.0-gpu-py37": "cu110-ubuntu16.04",
+            "pytorch-1.6-gpu-py36": "cu110-ubuntu18.04-v3",
+            "pytorch-1.6.0-gpu-py36": "cu110-ubuntu18.04",
+        }
+        key = "-".join([framework, tag])
+        if key in container_versions:
+            tag = "-".join([tag, container_versions[key]])
+
     if tag:
         repo += ":{}".format(tag)
 
@@ -217,6 +239,23 @@ def _processor(instance_type, available_processors):
     return processor
 
 
+def _should_auto_select_container_version(instance_type, distribution):
+    """Returns a boolean that indicates whether to use an auto-selected container version."""
+    p4d = False
+    if instance_type:
+        # looks for either "ml.<family>.<size>" or "ml_<family>"
+        match = re.match(r"^ml[\._]([a-z\d]+)\.?\w*$", instance_type)
+        if match:
+            family = match[1]
+            p4d = family == "p4d"
+
+    smdistributed = False
+    if distribution:
+        smdistributed = "smdistributed" in distribution
+
+    return p4d or smdistributed
+
+
 def _validate_py_version_and_set_if_needed(py_version, version_config, framework):
     """Checks if the Python version is one of the supported versions."""
     if "repository" in version_config:
