@@ -38,6 +38,142 @@ _UNUSED_ARN = "local:arn-does-not-matter"
 HEALTH_CHECK_TIMEOUT_LIMIT = 120
 
 
+class _LocalProcessingJob:
+    """Defines and starts a local processing job."""
+
+    _STARTING = "Starting"
+    _PROCESSING = "Processing"
+    _COMPLETED = "Completed"
+
+    def __init__(self, container):
+        """Creates a local processing job.
+
+        Args:
+            container: the local container object.
+        """
+        self.container = container
+        self.state = "Created"
+        self.start_time = None
+        self.end_time = None
+        self.processing_job_name = ""
+        self.processing_inputs = None
+        self.processing_output_config = None
+        self.environment = None
+
+    def start(self, processing_inputs, processing_output_config, environment, processing_job_name):
+        """Starts a local processing job.
+
+        Args:
+            processing_inputs: The processing input configuration.
+            processing_output_config: The processing input configuration.
+            environment: The collection of environment variables passed to the job.
+            processing_job_name: The processing job name.
+        """
+        self.state = self._STARTING
+
+        for item in processing_inputs:
+            if "DatasetDefinition" in item:
+                raise RuntimeError("DatasetDefinition is not currently supported in Local Mode")
+
+            try:
+                s3_input = item["S3Input"]
+            except KeyError:
+                raise ValueError("Processing input must have a valid ['S3Input']")
+
+            item["DataUri"] = s3_input["S3Uri"]
+
+            if "S3InputMode" in s3_input and s3_input["S3InputMode"] != "File":
+                raise RuntimeError(
+                    "S3InputMode: %s is not currently supported in Local Mode"
+                    % s3_input["S3InputMode"]
+                )
+
+            if (
+                "S3DataDistributionType" in s3_input
+                and s3_input["S3DataDistributionType"] != "FullyReplicated"
+            ):
+                raise RuntimeError(
+                    "DataDistribution: %s is not currently supported in Local Mode"
+                    % s3_input["S3DataDistributionType"]
+                )
+
+            if "S3CompressionType" in s3_input and s3_input["S3CompressionType"] != "None":
+                raise RuntimeError(
+                    "CompressionType: %s is not currently supported in Local Mode"
+                    % s3_input["S3CompressionType"]
+                )
+
+        if processing_output_config and "Outputs" in processing_output_config:
+            processing_outputs = processing_output_config["Outputs"]
+
+            for item in processing_outputs:
+                if "FeatureStoreOutput" in item:
+                    raise RuntimeError(
+                        "FeatureStoreOutput is not currently supported in Local Mode"
+                    )
+
+                try:
+                    s3_output = item["S3Output"]
+                except KeyError:
+                    raise ValueError("Processing output must have a valid ['S3Output']")
+
+                if s3_output["S3UploadMode"] != "EndOfJob":
+                    raise RuntimeError(
+                        "UploadMode: %s is not currently supported in Local Mode."
+                        % s3_output["S3UploadMode"]
+                    )
+
+        self.start_time = datetime.datetime.now()
+        self.state = self._PROCESSING
+
+        self.processing_job_name = processing_job_name
+        self.processing_inputs = processing_inputs
+        self.processing_output_config = processing_output_config
+        self.environment = environment
+
+        self.container.process(
+            processing_inputs, processing_output_config, environment, processing_job_name
+        )
+
+        self.end_time = datetime.datetime.now()
+        self.state = self._COMPLETED
+
+    def describe(self):
+        """Describes a local processing job.
+
+        Returns:
+            An object describing the processing job.
+        """
+
+        response = {
+            "ProcessingJobArn": self.processing_job_name,
+            "ProcessingJobName": self.processing_job_name,
+            "AppSpecification": {
+                "ImageUri": self.container.image,
+                "ContainerEntrypoint": self.container.container_entrypoint,
+                "ContainerArguments": self.container.container_arguments,
+            },
+            "Environment": self.environment,
+            "ProcessingInputs": self.processing_inputs,
+            "ProcessingOutputConfig": self.processing_output_config,
+            "ProcessingResources": {
+                "ClusterConfig": {
+                    "InstanceCount": self.container.instance_count,
+                    "InstanceType": self.container.instance_type,
+                    "VolumeSizeInGB": 30,
+                    "VolumeKmsKeyId": None,
+                }
+            },
+            "RoleArn": "<no_role>",
+            "StoppingCondition": {"MaxRuntimeInSeconds": 86400},
+            "ProcessingJobStatus": self.state,
+            "ProcessingStartTime": self.start_time,
+            "ProcessingEndTime": self.end_time,
+        }
+
+        return response
+
+
 class _LocalTrainingJob(object):
     """Placeholder docstring"""
 
@@ -47,10 +183,6 @@ class _LocalTrainingJob(object):
     _states = ["Starting", "Training", "Completed"]
 
     def __init__(self, container):
-        """
-        Args:
-            container:
-        """
         self.container = container
         self.model_artifacts = None
         self.state = "created"
@@ -58,13 +190,7 @@ class _LocalTrainingJob(object):
         self.end_time = None
 
     def start(self, input_data_config, output_data_config, hyperparameters, job_name):
-        """
-        Args:
-            input_data_config:
-            output_data_config:
-            hyperparameters:
-            job_name:
-        """
+        """Placeholder docstring."""
         for channel in input_data_config:
             if channel["DataSource"] and "S3DataSource" in channel["DataSource"]:
                 data_distribution = channel["DataSource"]["S3DataSource"]["S3DataDistributionType"]
@@ -116,12 +242,6 @@ class _LocalTransformJob(object):
     _COMPLETED = "Completed"
 
     def __init__(self, transform_job_name, model_name, local_session=None):
-        """
-        Args:
-            transform_job_name:
-            model_name:
-            local_session:
-        """
         from sagemaker.local import LocalSession
 
         self.local_session = local_session or LocalSession()
@@ -230,8 +350,7 @@ class _LocalTransformJob(object):
         return response
 
     def _get_container_environment(self, **kwargs):
-        """Get all the Environment variables that will be passed to the
-        container
+        """Get all the Environment variables that will be passed to the container.
 
         Certain input fields such as BatchStrategy have different values for
         the API vs the Environment variables, such as SingleRecord vs
@@ -274,8 +393,9 @@ class _LocalTransformJob(object):
         return environment
 
     def _get_required_defaults(self, **kwargs):
-        """Return the default values for anything that was not provided by
-        either the user or the container
+        """Return the default values.
+
+         The values might be anything that was not provided by either the user or the container
 
         Args:
             **kwargs: current transform arguments
@@ -375,11 +495,6 @@ class _LocalModel(object):
     """Placeholder docstring"""
 
     def __init__(self, model_name, primary_container):
-        """
-        Args:
-            model_name:
-            primary_container:
-        """
         self.model_name = model_name
         self.primary_container = primary_container
         self.creation_time = datetime.datetime.now()
@@ -400,12 +515,6 @@ class _LocalEndpointConfig(object):
     """Placeholder docstring"""
 
     def __init__(self, config_name, production_variants, tags=None):
-        """
-        Args:
-            config_name:
-            production_variants:
-            tags:
-        """
         self.name = config_name
         self.production_variants = production_variants
         self.tags = tags
@@ -432,13 +541,6 @@ class _LocalEndpoint(object):
 
     def __init__(self, endpoint_name, endpoint_config_name, tags=None, local_session=None):
         # runtime import since there is a cyclic dependency between entities and local_session
-        """
-        Args:
-            endpoint_name:
-            endpoint_config_name:
-            tags:
-            local_session:
-        """
         from sagemaker.local import LocalSession
 
         self.local_session = local_session or LocalSession()
@@ -501,10 +603,7 @@ class _LocalEndpoint(object):
 
 
 def _wait_for_serving_container(serving_port):
-    """
-    Args:
-        serving_port:
-    """
+    """Placeholder docstring."""
     i = 0
     http = urllib3.PoolManager()
 
@@ -525,11 +624,7 @@ def _wait_for_serving_container(serving_port):
 
 
 def _perform_request(endpoint_url, pool_manager=None):
-    """
-    Args:
-        endpoint_url:
-        pool_manager:
-    """
+    """Placeholder docstring."""
     http = pool_manager or urllib3.PoolManager()
     try:
         r = http.request("GET", endpoint_url)
